import KeyboardArrowDownIcon from '@mui/icons-material/KeyboardArrowDown';
import KeyboardArrowUpIcon from '@mui/icons-material/KeyboardArrowUp';
import { Collapse, useTheme } from '@mui/material';
import IconButton from '@mui/material/IconButton';
import clsx from 'clsx';
import React, { ReactNode, useState } from 'react';
import { WithChildren } from '../../helpers/withChildren';
// import s from './InfoBlock.module.css';

type Props = WithChildren<{
  title: string;
  titleIcon?: ReactNode;
  tooltip?: ReactNode;
  expandable?: boolean;
  className?: string;
  isOpenProp?: boolean;
  onClickHandler?: () => void;
  noBorder?: boolean;
  disabled?: boolean;
  description?: string;
  iconGap?: string;
}>;

export const UiInfoBlock: React.FC<Props> = ({
  title,
  titleIcon,
  tooltip,
  expandable,
  children,
  className,
  isOpenProp,
  onClickHandler,
  noBorder,
  disabled,
  description,
  iconGap,
}) => {
  const theme = useTheme();
  const isDarkTheme = theme.palette.mode === 'dark';
  const [isOpen, setIsOpen] = useState(false);
  const toggleBlockHandler = () => {
    expandable && setIsOpen(!isOpen);
  };

  const isOpened = isOpenProp !== undefined ? isOpenProp : isOpen;
  return (
    <div className={clsx(className, isDarkTheme && 'dark')}>
      <div
        onClick={onClickHandler ? onClickHandler : toggleBlockHandler}
        className={`bg-[#e5e5e5] dark:bg-[#263648] py-1.5 px-6 rounded-t-[4px] flex items-center justify-between w-full  ${
          description ? 'min-h-[60px]' : 'h-9'
        }`}
        style={{
          cursor: expandable ? (disabled ? 'not-allowed' : 'pointer') : 'auto',
        }}
      >
        <div className={`flex`} style={{ gap: iconGap }}>
          {titleIcon}
          <div>
            <div className={'flex items-center'}>
              {tooltip && <p className={'mt-[3px] mr-4'}>{tooltip}</p>}
              <p className={'font-bold'}>{title}</p>
            </div>

            {description && (
              <div
                className={
                  'max-w-full break-all font-normal text-sm opacity-50 text-[#0D0B0C] dark:text-[#FFFEFE] '
                }
              >
                {description}
              </div>
            )}
          </div>
        </div>
        {expandable && (
          <IconButton
            aria-label="expand row"
            size="small"
            sx={{ cursor: disabled ? 'not-allowed' : 'pointer' }}
          >
            {isOpened ? <KeyboardArrowUpIcon /> : <KeyboardArrowDownIcon />}
          </IconButton>
        )}
      </div>

      {/* Block content  */}
      <Collapse in={expandable ? isOpened : true} sx={{ width: '100%' }}>
        <div
          className={clsx(
            !noBorder && 'border',
            'bg-white dark:bg-[#222f40] border-[#e5e5e5] dark:border-[#263648] rounded-b-[4px]'
          )}
        >
          {children}
        </div>
      </Collapse>
    </div>
  );
};
